==> qtjambi-positioning-debuginfo-macos-5.15.17.jar: sources/QtJambiPositioning/QGeoAreaMonitorSource_shell.h <==
#ifndef QGEOAREAMONITORSOURCE_SHELL_H
#define QGEOAREAMONITORSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtPositioning/qgeoareamonitorsource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/CoreAPI>
#include <QtPositioning/qgeoareamonitorinfo.h>
#include <QtPositioning/qgeopositioninfo.h>
#include <QtPositioning/qgeopositioninfosource.h>
#include <QtPositioning/qgeoshape.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGeoAreaMonitorSource_shell : public QGeoAreaMonitorSource, public QtJambiShellInterface
{
public:
    QGeoAreaMonitorSource_shell(QObject* parent0);
    ~QGeoAreaMonitorSource_shell() override;

    QList<QGeoAreaMonitorInfo> activeMonitors() const override;
    QList<QGeoAreaMonitorInfo> activeMonitors(const QGeoShape& lookupArea0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoAreaMonitorSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QGeoPositionInfoSource* positionInfoSource() const override;
    bool requestUpdate(const QGeoAreaMonitorInfo& monitor0, const char* signal1) override;
    void setPositionInfoSource(QGeoPositionInfoSource* source0) override;
    bool startMonitoring(const QGeoAreaMonitorInfo& monitor0) override;
    bool stopMonitoring(const QGeoAreaMonitorInfo& monitor0) override;
    QGeoAreaMonitorSource::AreaMonitorFeatures supportedAreaMonitorFeatures() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGeoAreaMonitorSource_access : public QGeoAreaMonitorSource
{
    jobject __qt_activeMonitors(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_activeMonitors_cref_QGeoShape_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID lookupArea0) const;
    jint __qt_error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_positionInfoSource(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_requestUpdate_cref_QGeoAreaMonitorInfo_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID monitor0, jobject signal1);
    void __qt_setPositionInfoSource_QGeoPositionInfoSource_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0);
    jboolean __qt_startMonitoring_cref_QGeoAreaMonitorInfo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID monitor0);
    jboolean __qt_stopMonitoring_cref_QGeoAreaMonitorInfo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID monitor0);
    jint __qt_supportedAreaMonitorFeatures(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QGEOAREAMONITORSOURCE_SHELL_H

==> qtjambi-positioning-debuginfo-macos-6.5.3.jar: sources/QtJambiPositioning/QGeoAreaMonitorSource_shell.h <==
#ifndef QGEOAREAMONITORSOURCE_SHELL_H
#define QGEOAREAMONITORSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtPositioning/qgeoareamonitorsource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/CoreAPI>
#include <QtPositioning/qgeoareamonitorinfo.h>
#include <QtPositioning/qgeopositioninfo.h>
#include <QtPositioning/qgeopositioninfosource.h>
#include <QtPositioning/qgeoshape.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGeoAreaMonitorSource_shell : public QGeoAreaMonitorSource, public QtJambiShellInterface
{
public:
    QGeoAreaMonitorSource_shell(QObject* parent0);
    ~QGeoAreaMonitorSource_shell() override;

    QList<QGeoAreaMonitorInfo> activeMonitors() const override;
    QList<QGeoAreaMonitorInfo> activeMonitors(const QGeoShape& lookupArea0) const override;
    QVariant backendProperty(const QString& name0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoAreaMonitorSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QGeoPositionInfoSource* positionInfoSource() const override;
    bool requestUpdate(const QGeoAreaMonitorInfo& monitor0, const char* signal1) override;
    bool setBackendProperty(const QString& name0, const QVariant& value1) override;
    void setPositionInfoSource(QGeoPositionInfoSource* source0) override;
    bool startMonitoring(const QGeoAreaMonitorInfo& monitor0) override;
    bool stopMonitoring(const QGeoAreaMonitorInfo& monitor0) override;
    QGeoAreaMonitorSource::AreaMonitorFeatures supportedAreaMonitorFeatures() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGeoAreaMonitorSource_access : public QGeoAreaMonitorSource
{
    jobject __qt_activeMonitors(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_activeMonitors_cref_QGeoShape_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID lookupArea0) const;
    jobject __qt_backendProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jint __qt_error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_positionInfoSource(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_requestUpdate_cref_QGeoAreaMonitorInfo_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID monitor0, jobject signal1);
    jboolean __qt_setBackendProperty_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1);
    void __qt_setPositionInfoSource_QGeoPositionInfoSource_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0);
    jboolean __qt_startMonitoring_cref_QGeoAreaMonitorInfo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID monitor0);
    jboolean __qt_stopMonitoring_cref_QGeoAreaMonitorInfo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID monitor0);
    jint __qt_supportedAreaMonitorFeatures(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QGEOAREAMONITORSOURCE_SHELL_H
